Class: Danger::Reporter
- Inherits:
-
Plugin
- Object
- Plugin
- Danger::Reporter
- Defined in:
- lib/dangermattic/plugins/common/reporter.rb
Overview
Handles reporting messages in the context of Danger, allowing the generation of warnings, errors, and simple messages in a Danger run.
Instance Method Summary collapse
-
#report(message:, type: :warning) ⇒ void
Report a message to be posted by Danger as an error (failing the build), a warning or a simple message.
Instance Method Details
#report(message:, type: :warning) ⇒ void
This method returns an undefined value.
Report a message to be posted by Danger as an error (failing the build), a warning or a simple message.
27 28 29 30 31 32 33 34 35 36 |
# File 'lib/dangermattic/plugins/common/reporter.rb', line 27 def report(message:, type: :warning) case type when :error failure() when :warning warn() when :message danger.() end end |